# <span class="badge package-variant-dataquery"></span> expr

## Objects

 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsConditions](./object-ExprTypeClassicConditionsConditions.md)
 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsConditionsEvaluator](./object-ExprTypeClassicConditionsConditionsEvaluator.md)
 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsConditionsOperator](./object-ExprTypeClassicConditionsConditionsOperator.md)
 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsConditionsQuery](./object-ExprTypeClassicConditionsConditionsQuery.md)
 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsConditionsReducer](./object-ExprTypeClassicConditionsConditionsReducer.md)
 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsResultAssertions](./object-ExprTypeClassicConditionsResultAssertions.md)
 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsTimeRange](./object-ExprTypeClassicConditionsTimeRange.md)
 * <span class="badge object-type-class"></span> [ExprTypeMathResultAssertions](./object-ExprTypeMathResultAssertions.md)
 * <span class="badge object-type-class"></span> [ExprTypeMathTimeRange](./object-ExprTypeMathTimeRange.md)
 * <span class="badge object-type-class"></span> [ExprTypeReduceResultAssertions](./object-ExprTypeReduceResultAssertions.md)
 * <span class="badge object-type-class"></span> [ExprTypeReduceSettings](./object-ExprTypeReduceSettings.md)
 * <span class="badge object-type-class"></span> [ExprTypeReduceTimeRange](./object-ExprTypeReduceTimeRange.md)
 * <span class="badge object-type-class"></span> [ExprTypeResampleResultAssertions](./object-ExprTypeResampleResultAssertions.md)
 * <span class="badge object-type-class"></span> [ExprTypeResampleTimeRange](./object-ExprTypeResampleTimeRange.md)
 * <span class="badge object-type-class"></span> [ExprTypeSqlResultAssertions](./object-ExprTypeSqlResultAssertions.md)
 * <span class="badge object-type-class"></span> [ExprTypeSqlTimeRange](./object-ExprTypeSqlTimeRange.md)
 * <span class="badge object-type-class"></span> [ExprTypeThresholdConditions](./object-ExprTypeThresholdConditions.md)
 * <span class="badge object-type-class"></span> [ExprTypeThresholdConditionsEvaluator](./object-ExprTypeThresholdConditionsEvaluator.md)
 * <span class="badge object-type-class"></span> [ExprTypeThresholdConditionsUnloadEvaluator](./object-ExprTypeThresholdConditionsUnloadEvaluator.md)
 * <span class="badge object-type-class"></span> [ExprTypeThresholdResultAssertions](./object-ExprTypeThresholdResultAssertions.md)
 * <span class="badge object-type-class"></span> [ExprTypeThresholdTimeRange](./object-ExprTypeThresholdTimeRange.md)
 * <span class="badge object-type-class"></span> [TypeClassicConditions](./object-TypeClassicConditions.md)
 * <span class="badge object-type-class"></span> [TypeMath](./object-TypeMath.md)
 * <span class="badge object-type-class"></span> [TypeMathOrTypeReduceOrTypeResampleOrTypeClassicConditionsOrTypeThresholdOrTypeSql](./object-TypeMathOrTypeReduceOrTypeResampleOrTypeClassicConditionsOrTypeThresholdOrTypeSql.md)
 * <span class="badge object-type-class"></span> [TypeReduce](./object-TypeReduce.md)
 * <span class="badge object-type-class"></span> [TypeResample](./object-TypeResample.md)
 * <span class="badge object-type-class"></span> [TypeSql](./object-TypeSql.md)
 * <span class="badge object-type-class"></span> [TypeThreshold](./object-TypeThreshold.md)
 * <span class="badge object-type-disjunction"></span> [Expr](./object-Expr.md)
## Builders

 * <span class="badge builder"></span> [ExprTypeClassicConditionsConditions](./builder-ExprTypeClassicConditionsConditions.md)
 * <span class="badge builder"></span> [ExprTypeClassicConditionsConditionsEvaluator](./builder-ExprTypeClassicConditionsConditionsEvaluator.md)
 * <span class="badge builder"></span> [ExprTypeClassicConditionsConditionsOperator](./builder-ExprTypeClassicConditionsConditionsOperator.md)
 * <span class="badge builder"></span> [ExprTypeClassicConditionsConditionsQuery](./builder-ExprTypeClassicConditionsConditionsQuery.md)
 * <span class="badge builder"></span> [ExprTypeClassicConditionsConditionsReducer](./builder-ExprTypeClassicConditionsConditionsReducer.md)
 * <span class="badge builder"></span> [ExprTypeClassicConditionsResultAssertions](./builder-ExprTypeClassicConditionsResultAssertions.md)
 * <span class="badge builder"></span> [ExprTypeClassicConditionsTimeRange](./builder-ExprTypeClassicConditionsTimeRange.md)
 * <span class="badge builder"></span> [ExprTypeMathResultAssertions](./builder-ExprTypeMathResultAssertions.md)
 * <span class="badge builder"></span> [ExprTypeMathTimeRange](./builder-ExprTypeMathTimeRange.md)
 * <span class="badge builder"></span> [ExprTypeReduceResultAssertions](./builder-ExprTypeReduceResultAssertions.md)
 * <span class="badge builder"></span> [ExprTypeReduceSettings](./builder-ExprTypeReduceSettings.md)
 * <span class="badge builder"></span> [ExprTypeReduceTimeRange](./builder-ExprTypeReduceTimeRange.md)
 * <span class="badge builder"></span> [ExprTypeResampleResultAssertions](./builder-ExprTypeResampleResultAssertions.md)
 * <span class="badge builder"></span> [ExprTypeResampleTimeRange](./builder-ExprTypeResampleTimeRange.md)
 * <span class="badge builder"></span> [ExprTypeSqlResultAssertions](./builder-ExprTypeSqlResultAssertions.md)
 * <span class="badge builder"></span> [ExprTypeSqlTimeRange](./builder-ExprTypeSqlTimeRange.md)
 * <span class="badge builder"></span> [ExprTypeThresholdConditions](./builder-ExprTypeThresholdConditions.md)
 * <span class="badge builder"></span> [ExprTypeThresholdConditionsEvaluator](./builder-ExprTypeThresholdConditionsEvaluator.md)
 * <span class="badge builder"></span> [ExprTypeThresholdConditionsUnloadEvaluator](./builder-ExprTypeThresholdConditionsUnloadEvaluator.md)
 * <span class="badge builder"></span> [ExprTypeThresholdResultAssertions](./builder-ExprTypeThresholdResultAssertions.md)
 * <span class="badge builder"></span> [ExprTypeThresholdTimeRange](./builder-ExprTypeThresholdTimeRange.md)
 * <span class="badge builder"></span> [TypeClassicConditions](./builder-TypeClassicConditions.md)
 * <span class="badge builder"></span> [TypeMath](./builder-TypeMath.md)
 * <span class="badge builder"></span> [TypeReduce](./builder-TypeReduce.md)
 * <span class="badge builder"></span> [TypeResample](./builder-TypeResample.md)
 * <span class="badge builder"></span> [TypeSql](./builder-TypeSql.md)
 * <span class="badge builder"></span> [TypeThreshold](./builder-TypeThreshold.md)
## Functions

### <span class="badge function"></span> variant_config

variant_config returns the configuration related to __expr__ data queries.

This configuration describes how to unmarshal it, convert it to code, …

```python
def variant_config() -> variants.DataqueryConfig
```

